package cn.iocoder.yudao.module.customer.dal.mysql.customer;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.mapper.BaseMapperX;
import cn.iocoder.yudao.framework.mybatis.core.query.LambdaQueryWrapperX;
import cn.iocoder.yudao.module.customer.dal.dataobject.customer.line.CustomerLineDO;
import cn.iocoder.yudao.module.customer.vo.customer.line.CustomerLineDetailVO;
import cn.iocoder.yudao.module.customer.vo.customer.line.CustomerLineExportReqVO;
import cn.iocoder.yudao.module.customer.vo.customer.line.CustomerLinePageReqVO;
import cn.iocoder.yudao.module.customer.vo.customer.vo.UserVo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.ResultType;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 客户线路 Mapper
 *
 * @author yanghao
 */
@Mapper
public interface CustomerLineMapper extends BaseMapperX<CustomerLineDO> {

    default PageResult<CustomerLineDO> selectPage(CustomerLinePageReqVO reqVO) {
        return selectPage(reqVO, new LambdaQueryWrapperX<CustomerLineDO>()
                .eqIfPresent(CustomerLineDO::getCustomerId, reqVO.getCustomerId())
                .eqIfPresent(CustomerLineDO::getZhongPaoType, reqVO.getZhongPaoType())
                .eqIfPresent(CustomerLineDO::getDepartureId, reqVO.getDepartureId())
                .eqIfPresent(CustomerLineDO::getObjectiveIds, reqVO.getObjectiveIds())
                .betweenIfPresent(CustomerLineDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(CustomerLineDO::getId));
    }

    default List<CustomerLineDO> selectList(CustomerLineExportReqVO reqVO) {
        return selectList(new LambdaQueryWrapperX<CustomerLineDO>()
                .eqIfPresent(CustomerLineDO::getCustomerId, reqVO.getCustomerId())
                .eqIfPresent(CustomerLineDO::getDepartureId, reqVO.getDepartureId())
                .eqIfPresent(CustomerLineDO::getZhongPaoType, reqVO.getZhongPaoType())
                .eqIfPresent(CustomerLineDO::getObjectiveIds, reqVO.getObjectiveIds())
                .betweenIfPresent(CustomerLineDO::getCreateTime, reqVO.getBeginCreateTime(), reqVO.getEndCreateTime())
                .orderByDesc(CustomerLineDO::getId));
    }
    @ResultType(CustomerLineDetailVO.class)
    @Select("SELECT " +
            "l.*, " +
            " dep.title_zh as departureNameZh ," +
            " dep.title_en as departureNameEn ," +
            "GROUP_CONCAT(obje.title_zh) as  objectiveNameZh," +
            "GROUP_CONCAT(obje.title_en) as objectiveNameEn " +
            "" +
            "FROM " +
            "ecw_customer_line l " +
            "LEFT JOIN ecw_warehouse dep ON dep.id = l.departure_id AND dep.deleted = 0 " +
            " LEFT JOIN ecw_warehouse obje ON FIND_IN_SET(obje.id,l.objective_ids)  AND obje.deleted = 0 " +
            "WHERE " +
            "l.customer_id = #{customerId} " +
            " AND l.deleted = 0 " +
            "" +
            "GROUP BY l.id" +
            "")
    List<CustomerLineDetailVO> getCustomerLineDataListByCustomerId(Long customerId);
}
